==> igniteui-webcomponents-core-3.2.2.tgz: package/esm5/lib/WebCheckboxDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCheckboxBaseDescriptionMetadata } from "./WebCheckboxBaseDescriptionMetadata";
import { WebCheckboxDescription } from "./WebCheckboxDescription";
/**
 * @hidden
 */
var WebCheckboxDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebCheckboxDescriptionMetadata, _super);
    function WebCheckboxDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCheckboxDescriptionMetadata.b = function (a) {
        if (WebCheckboxDescriptionMetadata.a == null) {
            WebCheckboxDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCheckboxDescriptionMetadata.c(WebCheckboxDescriptionMetadata.a);
        }
        if (a.g(WebCheckboxDescriptionMetadata.a)) {
            return;
        }
        a.s(WebCheckboxDescriptionMetadata.a);
    };
    WebCheckboxDescriptionMetadata.c = function (a) {
        WebCheckboxBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:Checkbox");
        a.item("Indeterminate", "Boolean");
    };
    WebCheckboxDescriptionMetadata.d = function (a) {
        WebCheckboxDescriptionMetadata.b(a);
        a.u("WebCheckbox", function () { return new WebCheckboxDescription(); });
        a.t("WebCheckbox", WebCheckboxDescriptionMetadata.a);
    };
    WebCheckboxDescriptionMetadata.$t = markType(WebCheckboxDescriptionMetadata, 'WebCheckboxDescriptionMetadata');
    WebCheckboxDescriptionMetadata.a = null;
    return WebCheckboxDescriptionMetadata;
}(Base));
export { WebCheckboxDescriptionMetadata };

==> igniteui-webcomponents-core-3.5.0.tgz: package/esm5/lib/WebCheckboxDescriptionMetadata.js <==
/*
THIS INFRAGISTICS ULTIMATE SOFTWARE LICENSE  AGREEMENT ("AGREEMENT") LOCATED HERE:
https://www.infragistics.com/legal/license/igultimate-la
https://www.infragistics.com/legal/license/igultimate-eula
GOVERNS THE LICENSING, INSTALLATION AND USE OF INFRAGISTICS SOFTWARE. BY DOWNLOADING AND/OR INSTALLING AND USING INFRAGISTICS SOFTWARE:  you are indicating that you have read and understand this Agreement, and agree to be legally bound by it on behalf of the yourself and your company.
*/
import * as tslib_1 from "tslib";
import { Base, String_$type, markType } from "./type";
import { Dictionary$2 } from "./Dictionary$2";
import { WebCheckboxBaseDescriptionMetadata } from "./WebCheckboxBaseDescriptionMetadata";
import { WebCheckboxDescription } from "./WebCheckboxDescription";
/**
 * @hidden
 */
var WebCheckboxDescriptionMetadata = /** @class */ /*@__PURE__*/ (function (_super) {
    tslib_1.__extends(WebCheckboxDescriptionMetadata, _super);
    function WebCheckboxDescriptionMetadata() {
        return _super !== null && _super.apply(this, arguments) || this;
    }
    WebCheckboxDescriptionMetadata.b = function (a) {
        if (WebCheckboxDescriptionMetadata.a == null) {
            WebCheckboxDescriptionMetadata.a = new Dictionary$2(String_$type, String_$type, 0);
            WebCheckboxDescriptionMetadata.c(WebCheckboxDescriptionMetadata.a);
        }
        if (a.j(WebCheckboxDescriptionMetadata.a)) {
            return;
        }
        a.y(WebCheckboxDescriptionMetadata.a);
    };
    WebCheckboxDescriptionMetadata.c = function (a) {
        WebCheckboxBaseDescriptionMetadata.c(a);
        a.item("__qualifiedNameTS", "String:Checkbox");
        a.item("__tagNameWC", "String:igc-checkbox");
        a.item("Indeterminate", "Boolean");
    };
    WebCheckboxDescriptionMetadata.d = function (a) {
        WebCheckboxDescriptionMetadata.b(a);
        a.aa("WebCheckbox", function () { return new WebCheckboxDescription(); });
        a.z("WebCheckbox", WebCheckboxDescriptionMetadata.a);
    };
    WebCheckboxDescriptionMetadata.$t = markType(WebCheckboxDescriptionMetadata, 'WebCheckboxDescriptionMetadata');
    WebCheckboxDescriptionMetadata.a = null;
    return WebCheckboxDescriptionMetadata;
}(Base));
export { WebCheckboxDescriptionMetadata };
